@@ -3,7 +3,7 @@
 // Purpose:    Non-virtual archive stuff
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2019 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 #include "wx/wxprec.h" 
@@ -1328,7 +1328,7 @@ if (endExt == filetype) return zt_invalid;  // Check there IS an ext (AfterLast(
 prevExt = (filetype.BeforeLast(wxT('.'))).AfterLast(wxT('.')); // Get any previous ext, in case of foo.tar.gz
 
 if (endExt==wxT("htb"))  return zt_htb;
-if (endExt==wxT("zip"))  return zt_zip;
+if (endExt==wxT("zip") || endExt==wxT("xpi"))  return zt_zip; // 'xpi' is used for a Firefox browser addon, but it's really just a zip
 
 if (endExt==wxT("tar"))                                                 return zt_taronly;
 if (endExt==wxT("cpio"))                                                return zt_cpio;
