@@ -3,7 +3,7 @@
 // Purpose:    Bookmarks
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -494,6 +494,10 @@ struct Submenu* subfolder = FindSubmenuStruct(MenuStruct, LastSubmenuAddedto);
 if (subfolder==NULL) LastSubmenuAddedto =  wxString(wxT("/")) + _("Bookmarks");      // If not, use 'root'
 wxStaticText* folderStatic = (wxStaticText*)dlg.FindWindow(wxT("AddBookmark_Path")); // Put the default folder into static
 folderStatic->SetLabel(LastSubmenuAddedto);
+#if wxVERSION_NUMBER > 2904
+                  // Previously this was unnecessary; the statictexts knew their own size. However since wx3.1 they don't; perhaps because of the ellipsize feature
+                  folderStatic->SetMinSize(folderStatic->GetSizeFromTextSize(folderStatic->GetTextExtent(LastSubmenuAddedto)));
+#endif
 
 wxTextCtrl* bmkname = (wxTextCtrl*)dlg.FindWindow(wxT("AddBookmark_Bookmark"));      // Similarly load the bookmark & label names
 bmkname->ChangeValue(newpath);
@@ -565,6 +569,10 @@ if (MenuStruct.ID == data->GetID())                          // FindSubmenu does
 
 wxStaticText* folderStatic = (wxStaticText*)adddlg->FindWindow(wxT("AddBookmark_Path"));  // Put the default folder into static
 folderStatic->SetLabel(LastSubmenuAddedto);                  // Load the new default into AddBookmarks dialog
+#if wxVERSION_NUMBER >= 3100
+  folderStatic->SetMinSize(folderStatic->GetSizeFromTextSize(folderStatic->GetTextExtent(LastSubmenuAddedto)));
+#endif
+
 adddlg->GetSizer()->Layout();                                // For some reason, if we don't do this, the new folderStatic is LeftJustified, not centred
 }
 
