@@ -65,6 +65,10 @@ time_t AccessTime(){ return statstruct->st_atime; }               // Time last a
 time_t ModificationTime(){ return statstruct->st_mtime; }         // Time last modified
 time_t ChangedTime(){ return statstruct->st_ctime; }              // Time last Admin-changed
 
+static bool ModifyFileTimes(const wxString& fpath, const wxString& ComparisonFpath); // Sets the fpath's atime/mtime to that of ComparisonFpath
+bool ModifyFileTimes(const wxString& ComparisonFpath);            // Ditto to set this particular FileData from another filepath
+bool ModifyFileTimes(time_t mt);                                  // Ditto to set this particular FileData from a time_t
+
 wxULongLong Size(){ return statstruct->st_size; }                 // Size in bytes
 wxString GetParsedSize();                                         // Returns the size, but in bytes, KB or MB according to magnitude. (Uses global function)
 blksize_t GetBlocksize(){ return statstruct->st_blksize; }        // Returns filesystem's blocksize
@@ -151,6 +155,7 @@ struct Filetype_Struct                  // Struct to hold the filetype data with
   
     Filetype_Struct& operator=(const Filetype_Struct& fs){ AppName = fs.AppName; Ext = fs.Ext; Filepath = fs.Filepath;
                                                       Command = fs.Command; WorkingDir = fs.WorkingDir; return *this; }                                                   
+    void DeDupExt();
     void Clear(){ AppName.Clear(); Ext.Clear(); Filepath.Clear(); Command.Clear(); WorkingDir.Clear(); }
   };
 
@@ -313,7 +318,7 @@ bool DeduceExt();                         // Which bit of a filepath should we c
 bool GetLaunchCommandFromExt();
 void AddApplicationToExtdata(struct Filetype_Struct& ftype);    // Add submenu application for a particular extension, adding ext if needed
 void RemoveApplicationFromExtdata(struct Filetype_Struct& ftype); // Remove application described by ftype from the Extdata structarray
-int GetDefaultApplicForExt(wxString& Ext);                      // Given an ext, find its default applic, if any. Returns -1 if none
+int GetDefaultApplicForExt(const wxString& Ext);                // Given an ext, find its default applic, if any. Returns -1 if none
 void UpdateDefaultApplics(const struct Filetype_Struct& oldftype, const struct Filetype_Struct& newftype);  // Update default data after Edit
 
 FileData *stat;
