@@ -182,7 +182,8 @@ if (x > clx)                                                    // If the textex
   { wxString dots(wxT(".../")); int dx, dy; box->GetTextExtent(dots, &dx, &dy);  // make a string with .../ in it, and get *its* textextent too
     filepath = filepath.AfterFirst(wxFILE_SEP_PATH);            // We know it'll begin with /
     do
-      { filepath = filepath.AfterFirst(wxFILE_SEP_PATH);        // Now go thru the path, progressively chopping off its head until it plus dots will fit
+      { if (filepath.Find(wxFILE_SEP_PATH) == wxNOT_FOUND) return filepath; // Better an overlong string than an empty one
+        filepath = filepath.AfterFirst(wxFILE_SEP_PATH);        // Now go thru the path, progressively chopping off its head until it plus dots will fit
         box->GetTextExtent(filepath, &x, &y);
       }
      while  ((x+dx) > clx);
@@ -191,6 +192,23 @@ if (x > clx)                                                    // If the textex
 return filepath;                                                // Return the untruncated version, as it fitted anyway
 }
 
+wxWindow* InsertEllipsizingStaticText(wxString filepath, wxWindow* original, int insertAt/* = -1*/)  // Insert a self-truncating wxStaticText
+{
+if (filepath.empty() || !original) return (wxWindow*)NULL;
+
+// Since wx3.0 a wxStaticText can self-truncate. However wxCrafter can't currently set that styleflag, and it can't be applied retrospectively
+// So hide the XRC-loaded control and use a new one. Not the most elegant solution, but it works
+wxStaticText* ElipsizePathStatic = new wxStaticText(original->GetParent(), wxID_ANY, filepath, wxDefaultPosition, wxDefaultSize, wxST_ELLIPSIZE_START);
+wxSizer* psizer = original->GetContainingSizer();
+if (psizer)
+ { if (insertAt > -1) psizer->Insert(insertAt, ElipsizePathStatic, 0, wxEXPAND);
+     else psizer->Add(ElipsizePathStatic, 0, wxEXPAND);
+   psizer->Layout();
+ }
+original->Hide();
+return ElipsizePathStatic;
+}
+
 void QueryWrapWithShell(wxString& command)  // Wraps command with sh -c if appropriate
 {
 if (command.Contains(wxT("sh -c"))) return;     // We don't need two of them
@@ -296,6 +314,62 @@ wxConfigBase::Get()->Write(address + wxT("/ht"), sz.GetHeight());
 wxConfigBase::Get()->Write(address + wxT("/wd"), sz.GetWidth());
 }
 
+// The next 2 functions are compatability ones: a change in wx3.1.2 gave e.g. wxFONTWEIGHT_NORMAL a value of 400; previously it was 90
+#if wxVERSION_NUMBER > 3101
+  wxFontWeight LoadFontWeight(const wxString& configpath)
+#else
+  int LoadFontWeight(const wxString& configpath)
+#endif
+{
+int wt = wxConfigBase::Get()->Read(configpath + "weight", (long)-1); // See if there's a <wx3.1.2 value stored
+int wt32 = wxConfigBase::Get()->Read(configpath + "weight_wx3.2", (long)-1); // and a >wx3.1.1 one
+#if wxVERSION_NUMBER > 3101
+  if (wt32 == -1)
+    { switch(wt)
+        { case 91: wt32 = wxFONTWEIGHT_LIGHT; break;
+          case 92: wt32 = wxFONTWEIGHT_BOLD;  break;
+          default: wt32 = wxFONTWEIGHT_NORMAL;
+        }
+      wxConfigBase::Get()->Write(configpath + "weight_wx3.2", (long)wt32);
+    }
+  return (wxFontWeight)wt32;
+#else // < wx3.1.2
+  if ((wt == -1) || (wt < 90) || (wt > 92)) // Either no previous value, or a value set by an unfixed >wx3.1.1 instance
+    { switch(wt32)
+        { case 300: wt = wxFONTWEIGHT_LIGHT; break;
+          case 700: wt = wxFONTWEIGHT_BOLD;  break;
+          default:  wt = wxFONTWEIGHT_NORMAL;
+        }
+      wxConfigBase::Get()->Write(configpath + "weight", (long)wt);
+    }
+  return wt;
+#endif
+}
+
+void SaveFontWeight(const wxString& configpath, int fontweight)
+{
+int wt, wt32;
+#if wxVERSION_NUMBER > 3101
+  wxConfigBase::Get()->Write(configpath + "weight_wx3.2", (long)fontweight);
+  if (wxConfigBase::Get()->Exists(configpath + "weight"))
+    { switch(fontweight)  // There's a pre-wx3.1.2 entry in the config, so update that too
+        { case 300: wt = 91; break;
+          case 700: wt = 92; break;
+          default:  wt = 90;
+        }
+      wxConfigBase::Get()->Write(configpath + "weight", (long)wt);
+    }
+#else
+  wxConfigBase::Get()->Write(configpath + "weight", (long)fontweight);
+  switch(fontweight) // Future-proof by saving in >3.1.1 format too
+    { case 91: wt32 = 300; break;
+      case 92: wt32 = 700; break;
+      default: wt32 = 400;
+    }
+  wxConfigBase::Get()->Write(configpath + "weight_wx3.2", (long)wt32);
+#endif
+}
+
 #include <sys/utsname.h>
 #include "wx/tokenzr.h"
 
@@ -432,6 +506,22 @@ if (!RETAIN_REL_TARGET && ContainsRelativeSymlinks(orig.GetFilepath()))
 return true;
 }
 
+wxString LocateLibrary(const wxString& lib) // Search ldconfig output to find a lib's filepath. 'lib' can/will be a partial name e.g. 'rsvg'
+{
+wxCHECK_MSG(!lib.empty(), "", "Empty parameter");
+
+wxArrayString output, errors;
+long ans = wxExecute("sh -c \"/sbin/ldconfig -p | grep " + lib + '\"', output,errors);
+if (ans != 0 || output.IsEmpty()) return "";
+
+wxString fpath = output.Item(0).AfterLast(' ');
+FileData stat(fpath);
+if (stat.IsValid())
+  return fpath;
+
+return "";
+}
+
 //-----------------------------------------------------------------------------------------------------------------------
 IMPLEMENT_DYNAMIC_CLASS(FileDirDlg, wxDialog)
 
@@ -984,10 +1074,11 @@ wxString PasswordManager::GetPasswd() const // Decrypts and returns the password
 {
 return docrypt(m_password, m_key);
 }
+
 //-------------------------------------------------------------------------------------------------------------------------------------------
 
-
 PasteThreadStatuswriter::PasteThreadStatuswriter()
+  : m_cumsize(0), m_expectedsize(0)
 {
 m_timer.SetOwner(this);
 Connect(wxEVT_TIMER, wxTimerEventHandler(PasteThreadStatuswriter::OnTimer), NULL, this);
@@ -1001,7 +1092,7 @@ static wxString throbbers[] = { wxT("*......"), wxT(".*....."), wxT("..*...."),
 wxString message(wxT("Pasting "));
 message << throbbers[++count % 7];
 
-MyFrame::mainframe->SetStatusText(message + wxString::Format(wxT("  %s"), ParseSize(m_cumsize, true).c_str()), 1);
+MyFrame::mainframe->SetStatusText(message + wxString::Format(wxT("  %s of %s"), ParseSize(m_cumsize, true),  ParseSize(m_expectedsize, true)), 1);
 }
 
 ThreadsManager* ThreadsManager::ms_instance = NULL;
@@ -1243,6 +1334,17 @@ m_trashdir = trashdir;
 
 void PasteThreadSuperBlock::OnCompleted()
 {
+  // First deal with setting any modification times. This is needed when pasting a dir with contents, retaining the original mtimes;
+  // We can't set the time when creating the dir, as it'll be modified later when contents are added. So do it now the dust has settled
+while (m_ChangeMtimes.size())
+  { wxString filepath = m_ChangeMtimes.back().first;
+    time_t mt = m_ChangeMtimes.back().second;
+    FileData fd(filepath);
+    if (fd.IsValid())
+      fd.ModifyFileTimes(mt);
+    m_ChangeMtimes.pop_back();
+  }
+
 while (m_UnRedos.size())
   { UnRedo* entry = m_UnRedos.front().first;
     if (m_SuccessfullyPastedFilepaths.Index(m_UnRedos.front().second) == wxNOT_FOUND)
