@@ -3,7 +3,7 @@
 // Purpose:    Mounting partitions
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2019 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -866,7 +866,7 @@ for (size_t n=0; n < parent->PartitionArray->GetCount(); ++n)
   if (parent->PartitionArray->Item(n)->device == dev.BeforeFirst(' ')) // BeforeFirst in case of "/dev/sda1  $UUID/$LABEL"
     { if (GetDataFromMtab)    // If we're unmounting, we can't rely on the PartitionArray info:  the partition may not have been mounted where fstab intended
         { FstabMountptTxt->Clear();
-          struct mntent* mnt = parent->ReadMtab(dev);       // So see where it really is
+          struct mntent* mnt = parent->ReadMtab(dev.BeforeFirst(' ')); // So see where it really is
           if (mnt != NULL)   FstabMountptTxt->ChangeValue(wxString(mnt->mnt_dir, wxConvUTF8));
           return;
         }
