@@ -3,7 +3,7 @@
 // Purpose:    Notebook stuff
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -256,6 +256,9 @@ if (TemplateNo >= 0)
  
 config->Write(Path + wxT("showcommandline"), MyFrame::mainframe->Layout->CommandlineShowing);
 config->Write(Path + wxT("showterminal"), MyFrame::mainframe->Layout->EmulatorShowing);
+if ( MyFrame::mainframe->Layout->EmulatorShowing)
+  config->Write(Path + "terminalheight", MyFrame::mainframe->Layout->bottompanel->GetSize().GetHeight());
+
 config->Write(Path + wxT("saveonexit"), saveonexit);
 config->Write(Path + wxT("selectedpage"), GetSelection());
 
