@@ -5,7 +5,7 @@
 // See:        http://wxcode.sourceforge.net/components/treelistctrl/
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2019 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -1438,7 +1438,11 @@ static const int NO_IMAGE = -1;                                  // //
 
     if (item->IsSelected())
     {
+#if wxVERSION_NUMBER < 3104
         dc.SetBrush(*(m_hasFocus ? m_hilightBrush : m_hilightUnfocusedBrush));
+#else
+        dc.SetBrush(m_hasFocus ? m_hilightBrush : m_hilightUnfocusedBrush);
+#endif
     }
     else
     {
@@ -1707,6 +1711,50 @@ if (m_anchor)
     }
 }
 
+void MyTreeCtrl::ScrollToMidScreen(const wxTreeItemId& item, const wxString& START_DIR) // Improved version of wxGenericTreeCtrl::ScrollTo (which seems to show the item at the top/bottom)
+{
+if (!item.IsOk())
+  return;
+
+// const int PIXELS_PER_UNIT = 10;  // // This was set in src/generic/treectlg.cpp but the method below is more future-proof
+int xScrollUnits, PIXELS_PER_UNIT;
+GetScrollPixelsPerUnit(&xScrollUnits, &PIXELS_PER_UNIT);
+
+
+wxGenericTreeItem *gitem = (wxGenericTreeItem*) item.m_pItem;
+int itemY = gitem->GetY();
+
+int viewstart_x = 0;
+int viewstart_y = 0;
+GetViewStart( &viewstart_x, &viewstart_y );
+
+const int clientHeight = GetClientSize().y;
+int ScrollPageSize = GetScrollPageSize(wxVERTICAL);
+const int itemHeight = GetLineHeight(gitem) + 2;
+
+if ( itemY + itemHeight > viewstart_y*PIXELS_PER_UNIT + clientHeight )
+{ // ** I've left this branch here but, for our use-case, it's never entered **
+    // need to scroll down by enough to show this item fully
+    itemY += itemHeight - (clientHeight/2);
+
+    // because itemY below will be divided by PIXELS_PER_UNIT it may
+    // be rounded down, with the result of the item still only being
+    // partially visible, so make sure we are rounding up
+    itemY += PIXELS_PER_UNIT - 1;
+
+    Scroll(-1, (itemY - (clientHeight/2))/PIXELS_PER_UNIT);
+}
+/*else if ( itemY > viewstart_y*PIXELS_PER_UNIT )
+{
+    // item is already fully visible, don't do anything
+   // return;
+}*/
+
+ else
+  Scroll(-1, (viewstart_y + (ScrollPageSize/2)));
+}
+
+
 void MyTreeCtrl::OnScroll(wxScrollWinEvent& event)  // // Keeps the headerwindows in step with the treectrl colums
 {
 if (headerwindow != NULL) headerwindow->Refresh();
