@@ -3,7 +3,7 @@
 // Purpose:    Find/Grep/Locate, Terminal Emulator
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2020 David Hart
 // Licence:    wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 #ifndef TOOLSH
@@ -129,13 +129,15 @@ void OnButton(wxCommandEvent& event);
 void OnCheck(wxCommandEvent& event);
 void OnKeyDown(wxKeyEvent &event){ if (event.GetKeyCode() == wxID_CANCEL) EndModal(wxID_CANCEL); } // For some reason this doesn't happen otherwise :/
 void OnUpdateUI(wxUpdateUIEvent& event);
+void OnAsterixUpdateUI(wxUpdateUIEvent& event);
+
 void LoadCheckboxState();
 void SaveCheckboxState();
 void LoadCombosHistory();
 void SaveCombosHistory(int which);
 
 wxComboBox *SearchPattern, *PathFind;
-wxCheckBox *IgnoreCase, *PathCurrentDir, *PathHome, *PathRoot;
+wxCheckBox *IgnoreCase, *PrependAsterix, *AppendAsterix, *PathCurrentDir, *PathHome, *PathRoot;
 wxRadioButton *RBName, *RBPath, *RBRegex;
 Tools* parent;
 
